#
# spec file for package sdparm
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sdparm
Version:        1.10
Release:        lp150.1.7
Summary:        List or change SCSI disk parameters
License:        BSD-3-Clause
Group:          Hardware/Other
Url:            http://sg.danny.cz/sg/sdparm.html

#Freecode-URL:	http://freecode.com/projects/sdparm
Source:         http://sg.danny.cz/sg/p/%name-%version.tar.xz
BuildRequires:  libsgutils-devel
BuildRequires:  xz
Provides:       scsi:/sbin/sdparm

%description
SCSI disk parameters are held in mode pages. This utility lists or
changes those parameters. Other SCSI devices (or devices that use the
SCSI command set) such as CD/DVD and tape drives may also find parts of
sdparm useful. Requires the linux kernel 2.4 series or later. In the
2.6 series any device node the understands a SCSI command set may be
used (e.g. /dev/sda). In the 2.4 series SCSI device node may be used.

Warning: It is possible (but unlikely) to change SCSI disk settings
such that the disk stops operating or is slowed down. Use with care.

%prep
%setup -q

%build
# None of these is performance-critical, so use -Os rather than -O2:
CFLAGS=$(echo "%optflags" | sed 's/\-O2/-Os/')
%configure
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot" bindir="/sbin"

%files
%defattr(-,root,root)
/sbin/sas_disk_blink
/sbin/scsi_ch_swp
/sbin/sdparm
%_mandir/man8/*.8*
%doc README ChangeLog

%changelog
* Wed Aug 24 2016 alexander_naumov@opensuse.org
- Update to version 1.10
  * add --inhex=FN option for decoding without device present,
  FN is interpreted as response to mode sense(10) command
  * add --raw option to interpret FN as binary (def: ASCII hex)
  * add --pdt=PDT option for use with --inhex=FN
  * --quiet used twice hides changeable, default + saved
  * add IO advice hints grouping mode page (sbc4r06, 8)
  * add Unit serial number VPD page specific sanity check
  * add NO_PI_CHK to Supported block lengths and protection
  types VPD page
  * add Background operation control mpage (sbc4r07)
  * Read-write error recovery mpage: add Misaligned writes
  reporting field (MWR)
  * sync tape mpages with ssc5r02
  * add Block limits extension VPD page
  * add Device constituents VPD page
  * add LB protection VPD page (ssc5r02a)
  * LB provisioning VPD page: expand LBPRZ, add Minimum and
  Threshold percentage fields
  * device identification VPD page: add decoding for locally
  assigned UUIDs (spc5r08)
  * the --inhex=FN option together with --inquiry decodes
  FN as a single VPD page
  * improve lto5 and lto6 vendor mpage support
  * sync to spc5r08 and sbc4r10
  * add SAS G5 (22.5 Gbps) settings (spl4r06)
  * point svn:externals to rev 663 of sg3_utils
  * upgrade automake to version 1.15 (U15.10)
  * autogen.sh: upgrade to buildconf 20091223 version
* Sun Dec 28 2014 p.drouand@gmail.com
- Update to version 1.09
  + decode Third Party Copy VPD page
  + Supported block lengths and protection types (sbc4r01) +
    Block device characteristics extension VPD pages added
  + zoned block device characterics VPD page added (zbc-r01c)
  + fix manufacturer-assigned serial number VPD page length
  + device id VPD: T10 vendor identification designator clean up
  + block device characteristics VPD: add ZONED (sbc4r04)
  + SAS/SPL disconnect-reconnect mpage: expand
  + SAS protocol specific port mpage: add MAXR field (spl4r01)
  + standard inquiry response (sinq): add LU_CONG
  + change ibm vendor code to lto5 and lto6
  + point svn:externals to rev 620 of sg3_utils
  + upgrade automake to version 1.14.1
  + configure: add --disable-libsgutils so build bypasses that
    library if present
  + win32: some --wscan and compile fixes
* Wed Oct 23 2013 p.drouand@gmail.com
- Remove %%fillup_prereq and %%insserv_prereq; package doesn't provide
  any sysvinit script
* Thu Jun 13 2013 jengelh@inai.de
- Update to new upstream release 1.08
  * New utilities: scsi_ch_swp, sas_disk_blink
  * Tracked changes at t10.org since January 2012:
  * device id VPD: add protocol specific port identifier
  * control extension mpage: add max sense data length
  * power condition mpage: FIDCPC->CCF_IDLE, FSBCPC->CCF_STAND,
  FSTCPC->CCF_STOPP (spc4r34+)
  * caching mpage: add SYNC_PROG field (sbc3r33)
  * block device characteristics VPD page additions sbc3r34
  * extended inquiry vpd page: add max supported sense data length
  * protocol-specific port information VPD page for SAS SSP,
  persistent connection (spl3r2), power disable (spl3r3)
  * allow --readonly with --set= and --clear=
  * add placeholder for third party copy VPD page
  * supply more information if a UA occurs
- Normalized install procedure
- Build with libsgutils support
* Sun Apr 22 2012 puzel@suse.com
- Update to version 1.07
  - LB provisioning + Block limits VPD pages to sbc3r27
  - Enhanced phy control page: optical mode enabled (spl-r07)
  - Phy control and discover page: sync to spl2r02
  - sync with spc4r31+32 (handle status good with sense)
  - extented inquiry VPD: add POA_SUP, HRA_SUP and VSA_SUP
  - application tag mode page subcode 0xf0->0x2 (sbc3r28)
  - add 'sinq' pseudo VPD page for standard inquiry response
  - add power consumption mode and VPD pages (spc4r33)
  - point out some mode page numbers are vendor specific
* Tue May 24 2011 dimstar@opensuse.org
- Update to version 1.06:
  + allow upper and lower case in field, (mode and vpd) page,
    vendor, transport or command matching
  + control mode page: add ATMPE and RWWP fields (spc4r27)
  + extended inquiry vpd page: add extended self test completion
    minutes field (spc4r27)
  + power control mode page: PM_BG_PRECEDENCE field (spc4r24)
  - FIDCPC, FSBCPC, FSTCPC fields (spc4r25)
  + sbc3r25 renames 'thin' provisioning' to 'logical block
    provisioning'; changes mode+vpd page and field names
  - add Application tag mode page
  - add SITPUA bit to logical block provisioning mode page
  + fix '-eal' problem with vendor pages
  + point svn:externals to rev 334 of sg3_utils
* Fri Aug 13 2010 dimstar@opensuse.org
- Update to version 1.05:
  + add '--readonly' option especially for '-C start' and
    '-C stop' on ATA disks.
  + Control mode page updates (spc4r23)
  + add Control data protection mode page (ssc4r01)
  + block device characteristics VPD page: decode form factor
  + extended inquiry VPD page: activate_microcode+r_sup (spc4r23)
  + Automation device serial number and Data transfer device
    element address VPD pages (ssc4r01)
  + add SBC Referrals VPD page (sbc3r22)
  + expand SBC Thin provisioning VPD page (sbc3r22)
  + expand SBC Block limits VPD page (sbc3r22)
  + SAS-2.1 specification split, upper layers placed in SPL
  - add enable_slumber and enable_partial fields to
    Enhanced phy control mode page
  + add AM_MAINTAINER_MODE to configure.ac to lessen build issues
  + build infrastructure change to use libsgutils2 if available
- Changes from version 1.04:
  + add SAT ATA Power condition mode page (sat2r06)
  + add SBC Thin provisioning mode page (sbc3r20)
  + add SBC Thin provisioning VPD page (sbc3r20)
  + sync with spc4r21
  + add Power condition, update extended inquiry VPD pages
  + smc3: add Device capabilities + Extended device
    capabilities + Transport geometry parameters mode pages
  + prepare for Thin provisioning VPD and mode pages
  + expand block limits VPD page
  + update Power condition mode page
  + rename SAS-2 phy mode page to Enhanced phy control (SAS)
  + add ADC mode (sub)page place holders
  + print mode page descriptors in full in more contexts
  + add linux bsg support
  + scripts/sas_disk_blink: moved here from sg3_utils package
  + rework the '-w' option (win32) per sg_scan in sg3_utils
  + change SDPARM_* constants to SG_LIB_*
  + remove sdparm.html, refer to its url in sdparm.8
  + sdparm.spec: correction to configure call
* Tue Aug 12 2008 garloff@suse.de
- Update to sdparm-1.03:
  * supports more than one device on command linx
  * speed[=val] and profile commands for MMC
  * Extended Inquiry VPD page updated (spc4r15)
  * SAS protocol-specific port mpage (add CAWT, RTOL)
  * minor cleanups
* Fri May 23 2008 hare@suse.de
- Using 'Provides' keyword to clean update dependency.
* Thu Apr 24 2008 hare@suse.de
- Split off from the original scsi package.
